/* Copyright 2013-2015 NuoDB, Inc. All rights reserved */

#pragma once

namespace NuoDB
{
static const int    DATABASEMETADATA_VERSION        = 1;

/**
 * @brief   Indicates that it is not known whether the procedure returns a result
 *
 * A possible column value for PROCEDURE_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedures()
 */
static const int    procedureResultUnknown          = 0;

/**
 * @brief   Indicates that the procedure does not return a result
 *
 * A possible column value for PROCEDURE_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedures()
 */
static const int    procedureNoResult               = 1;

/**
 * @brief   Indicates that the procedure returns a result
 *
 * A possible column value for PROCEDURE_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedures()
 */
static const int    procedureReturnsResult          = 2;

/**
 * @brief   Indicates that the column type is unknown
 *
 * A possible column value for COLUMN_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureColumnUnknown          = 0;

/**
 * @brief   Indicates that the column stores IN parameters
 *
 * A possible column value for COLUMN_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureColumnIn               = 1;

/**
 * @brief   Indicates that the column stores INOUT parameters
 *
 * A possible column value for COLUMN_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureColumnInOut            = 2;

/**
 * @brief   Indicates that the column stores OUT parameters
 *
 * A possible column value for COLUMN_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureColumnOut              = 4;

/**
 * @brief   Indicates that the column stores return parameters
 *
 * A possible column value for COLUMN_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureColumnReturn           = 5;

/**
 * @brief   Indicates that the column stores results
 *
 * A possible column value for COLUMN_TYPE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureColumnResult           = 3;

static const int    procedureNoNulls                = 0;

/**
 * @brief   Indicates that NULL values are allowed
 *
 * A possible column value for NULLABLE in the ResultSet object returned 
 * by the method DatabaseMetaData::getProcedureColumns()
 */
static const int    procedureNullable               = 1;

static const int    procedureNullableUnknown        = 2;

/**
 * @brief   Indicates that NULL values are not allowed
 *
 * A possible column value for NULLABLE in the ResultSet object returned 
 * by the method DatabaseMetaData::getColumns()
 */
static const int    columnNoNulls                   = 0;

/**
 * @brief   Indicates that NULL values are allowed
 *
 * A possible column value for NULLABLE in the ResultSet object returned 
 * by the method DatabaseMetaData::getColumns()
 */
static const int    columnNullable                  = 1;

/**
 * @brief   Indicates that whether NULL values are allowed is unknown
 *
 * A possible column value for NULLABLE in the ResultSet object returned 
 * by the method DatabaseMetaData::getColumns()
 */
static const int    columnNullableUnknown           = 2;

static const int    bestRowTemporary                = 0;
static const int    bestRowTransaction              = 1;
static const int    bestRowSession                  = 2;
static const int    bestRowUnknown                  = 0;
static const int    bestRowNotPseudo                = 1;
static const int    bestRowPseudo                   = 2;
static const int    versionColumnUnknown            = 0;
static const int    versionColumnNotPseudo          = 1;
static const int    versionColumnPseudo             = 2;

/**
 * @brief   For the column UPDATE_RULE, indicates that when the primary key is 
 *          updated, the foreign key (imported key) is changed to agree with it.
 * 
 * For the column DELETE_RULE, it indicates that when the primary key is deleted, 
 * rows that imported that key are deleted.
 *
 * A possible column value for UPDATE_RULE and DELETE_RULE in the ResultSet 
 * object returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeyCascade              = 0;

/**
 * @brief   For the column UPDATE_RULE, indicates that when the primary key may 
 *          not be updated if it has been imported by another table as a foreign key. 
 * 
 * For the column DELETE_RULE, it indicates that a primary key may not be deleted 
 * if it has been imported by another table as a foreign key.
 *
 * A possible column value for UPDATE_RULE and DELETE_RULE in the ResultSet 
 * object returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeyRestrict             = 1;

/**
 * @brief   For the columns UPDATE_RULE and DELETE_RULE, indicates that when 
 *          the primary key is updated or deleted, the foreign key (imported 
 *          key) is changed to NULL.
 *
 * A possible column value for UPDATE_RULE and DELETE_RULE in the ResultSet 
 * object returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeySetNull              = 2;

/**
 * @brief   For the columns UPDATE_RULE and DELETE_RULE, indicates that if the 
 *          primary key has been imported, it cannot be updated or deleted.
 * 
 * A possible column value for UPDATE_RULE and DELETE_RULE in the ResultSet 
 * object returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeyNoAction             = 3;

/**
 * @brief   For the columns UPDATE_RULE and DELETE_RULE, indicates that if the 
 *          primary key is updated or deleted, the foreign key (imported key) is 
 *          set to the default value.
 *
 * A possible column value for UPDATE_RULE and DELETE_RULE in the ResultSet 
 * object returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeySetDefault           = 4;

/**
 * @brief   Indicates deferrability. See SQL-92 for a definition.
 *
 * A possible value for the column DEFERRABILITY in the ResultSet object 
 * returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeyInitiallyDeferred    = 5;

/**
 * @brief   Indicates deferrability. See SQL-92 for a definition.
 *
 * A possible value for the column DEFERRABILITY in the ResultSet object 
 * returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeyInitiallyImmediate   = 6;

/**
 * @brief   Indicates deferrability. See SQL-92 for a definition.
 *
 * A possible value for the column DEFERRABILITY in the ResultSet object 
 * returned by DatabaseMetaData::getImportedKeys()
 */
static const int    importedKeyNotDeferrable        = 7;

/**
 * @brief   Indicates that a NULL value is NOT allowed for this data type
 *
 * A possible value for the column NULLABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typeNoNulls                     = 0;

/**
 * @brief   Indicates that a NULL value is allowed for this data type
 *
 * A possible value for the column NULLABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typeNullable                    = 1;

/**
 * @brief   Indicates that it is not known whether a NULL value is allowed for 
 *          this data type
 *
 * A possible value for the column NULLABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typeNullableUnknown             = 2;

/**
 * @brief   Indicates that WHERE search clauses are not supported for this type
 *
 * A possible value for the column SEARCHABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typePredNone                    = 0;

/**
 * @brief   Indicates that the data type can be only used in WHERE search clauses 
 *          that use LIKE predicates
 *
 * A possible value for the column SEARCHABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typePredChar                    = 1;

/**
 * @brief   Indicates that the data type can only be used in WHERE search clauses 
 *          that do not use LIKE predicates
 *
 * A possible value for the column SEARCHABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typePredBasic                   = 2;

/**
 * @brief   Indicates that all WHERE search clauses can be used on this type
 *
 * A possible value for the column SEARCHABLE in the ResultSet object
 * returned by DatabaseMetaData::getTypeInfo()
 */
static const int    typeSearchable                  = 3;

static const int    tableIndexStatistic             = 0;
static const int    tableIndexClustered             = 1;
static const int    tableIndexHashed                = 2;

/**
 * @brief   Indicates that this table index is not a clustered index, a hashed 
 *          index or table statistics; it is something other than these
 *
 * A possible value for column TYPE in the ResultSet object returned by the 
 * method DatabaseMetaData::getIndexInfo().
 */
static const int    tableIndexOther                 = 3;

static const int    attributeNoNulls                = 0;
static const int    attributeNullable               = 1;
static const int    attributeNullableUnknown        = 2;
static const int    sqlStateXOpen                   = 1;
static const int    sqlStateSQL                     = 2;
static const int    sqlStateSQL99                   = sqlStateSQL;

/**
 * @brief   Indicates that type of the parameter or column is unknown
 *
 * A possible value for column COLUMN_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionColumnUnknown           = 0;

/**
 * @brief   Indicates that the parameter or column is an IN parameter
 *
 * A possible value for column COLUMN_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionColumnIn                = 1;

/**
 * @brief   Indicates that the parameter or column is an INOUT parameter
 *
 * A possible value for column COLUMN_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionColumnInOut             = 2;

/**
 * @brief   Indicates that the parameter or column is an OUT parameter
 *
 * A possible value for column COLUMN_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionColumnOut               = 3;

/**
 * @brief   Indicates that the parameter or column is a return value
 *
 * A possible value for column COLUMN_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionReturn                  = 4;

/**
 * @brief   Indicates that the parameter or column is a column in a result set
 *
 * A possible value for column COLUMN_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionColumnResult            = 5;

static const int    functionNoNulls                 = 0;

/**
 * @brief   Indicates that NULL values are allowed
 *
 * A possible value for column NULLABLE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctionColumns().
 */
static const int    functionNullable                = 1;

static const int    functionNullableUnknown         = 2;

/* unused */
static const int    functionResultUnknown           = 0;

/**
 * @brief   Indicates that the function does not return a table
 *
 * A possible value for column FUNCTION_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctions().
 */
static const int    functionNoTable                 = 1;

/**
 * @brief   Indicates that the function returns a table
 *
 * A possible value for column FUNCTION_TYPE in the ResultSet object returned by 
 * the method DatabaseMetaData::getFunctions().
 */
static const int    functionReturnsTable            = 2;
}
